@@ -14,7 +14,6 @@ from mistapi.api.v1.const import alarm_defs
 from mistapi.api.v1.const import ap_channels
 from mistapi.api.v1.const import ap_led_status
 from mistapi.api.v1.const import applications
-from mistapi.api.v1.const import call_events
 from mistapi.api.v1.const import client_events
 from mistapi.api.v1.const import countries
 from mistapi.api.v1.const import default_gateway_config
@@ -22,6 +21,10 @@ from mistapi.api.v1.const import device_events
 from mistapi.api.v1.const import device_models
 from mistapi.api.v1.const import insight_metrics
 from mistapi.api.v1.const import languages
+from mistapi.api.v1.const import license_types
 from mistapi.api.v1.const import mxedge_events
 from mistapi.api.v1.const import mxedge_models
+from mistapi.api.v1.const import nac_events
+from mistapi.api.v1.const import otherdevice_events
+from mistapi.api.v1.const import otherdevice_models
 from mistapi.api.v1.const import traffic_types
