@@ -12,6 +12,7 @@
 
 from mistapi import APISession as _APISession
 from mistapi.__api_response import APIResponse as _APIResponse
+import deprecation
 
 def optimizeInstallerRrm(mist_session:_APISession, site_name:str) -> _APIResponse:
     """
@@ -19,15 +20,17 @@ def optimizeInstallerRrm(mist_session:_APISession, site_name:str) -> _APIRespons
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str site_name        
+    site_name : str        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/installer/sites/{site_name}/optimize"
     query_params={}
