@@ -30,6 +30,7 @@ from mistapi.api.v1.orgs import devices
 from mistapi.api.v1.orgs import evpn_topologies
 from mistapi.api.v1.orgs import gatewaytemplates
 from mistapi.api.v1.orgs import guests
+from mistapi.api.v1.orgs import idpprofiles
 from mistapi.api.v1.orgs import insights
 from mistapi.api.v1.orgs import inventory
 from mistapi.api.v1.orgs import invites
@@ -37,9 +38,11 @@ from mistapi.api.v1.orgs import jsi
 from mistapi.api.v1.orgs import licenses
 from mistapi.api.v1.orgs import logs
 from mistapi.api.v1.orgs import maps
+from mistapi.api.v1.orgs import mist_nac
 from mistapi.api.v1.orgs import mxclusters
 from mistapi.api.v1.orgs import mxedges
 from mistapi.api.v1.orgs import mxtunnels
+from mistapi.api.v1.orgs import nac_clients
 from mistapi.api.v1.orgs import nacrules
 from mistapi.api.v1.orgs import nactags
 from mistapi.api.v1.orgs import networks
@@ -67,7 +70,10 @@ from mistapi.api.v1.orgs import subscriptions
 from mistapi.api.v1.orgs import templates
 from mistapi.api.v1.orgs import tickets
 from mistapi.api.v1.orgs import troubleshoot
+from mistapi.api.v1.orgs import vars
 from mistapi.api.v1.orgs import vpns
+from mistapi.api.v1.orgs import wan_client
+from mistapi.api.v1.orgs import wan_clients
 from mistapi.api.v1.orgs import webhooks
 from mistapi.api.v1.orgs import wired_clients
 from mistapi.api.v1.orgs import wlans
