@@ -12,22 +12,49 @@
 
 from mistapi import APISession as _APISession
 from mistapi.__api_response import APIResponse as _APIResponse
+import deprecation
 
+@deprecation.deprecated(deprecated_in="0.37.7", removed_in="0.52.0", current_version="0.46.1", details="function replaced with listOrgDevices")  
 def getOrgDevices(mist_session:_APISession, org_id:str) -> _APIResponse:
     """
-    API doc: https://doc.mist-lab.fr/#operation/getOrgDevices
+    API doc: https://doc.mist-lab.fr/#operation/listOrgDevices
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id        
+    org_id : str        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
+    """
+    uri = f"/api/v1/orgs/{org_id}/devices"
+    query_params={}
+    resp = mist_session.mist_get(uri=uri, query=query_params)
+    return resp
+    
+def listOrgDevices(mist_session:_APISession, org_id:str) -> _APIResponse:
+    """
+    API doc: https://doc.mist-lab.fr/#operation/listOrgDevices
+    
+    PARAMS
+    -----------
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
+    
+    PATH PARAMS
+    -----------
+    org_id : str        
+    
+    RETURN
+    -----------
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/devices"
     query_params={}
@@ -40,36 +67,49 @@ def countOrgDevices(mist_session:_APISession, org_id:str, distinct:str, hostname
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id        
+    org_id : str        
     
     QUERY PARAMS
     ------------
-    :param str distinct(hostname, site_id, model, mac, version, ip, mxtunnel_status, mxedge_id, lldp_system_name, lldp_system_desc, lldp_port_id, lldp_mgmt_addr)
-    :param str hostname - partial / full hostname
-    :param str site_id - site id
-    :param str model - device model
-    :param str mac - AP mac
-    :param str version - version
-    :param str ip_address
-    :param str mxtunnel_status(up, down) - MxTunnel status, up / down
-    :param str mxedge_id - Mist Edge id, if AP is connecting to a Mist Edge
-    :param str lldp_system_name - LLDP system name
-    :param str lldp_system_desc - LLDP system description
-    :param str lldp_port_id - LLDP port id
-    :param str lldp_mgmt_addr - LLDP management ip address
-    :param int page
-    :param int limit
-    :param int start
-    :param int end
-    :param str duration        
+    distinct : str{'hostname', 'site_id', 'model', 'mac', 'version', 'ip', 'mxtunnel_status', 'mxedge_id', 'lldp_system_name', 'lldp_system_desc', 'lldp_port_id', 'lldp_mgmt_addr'}, default: model
+    hostname : str
+      partial / full hostname
+    site_id : str
+      site id
+    model : str
+      device model
+    mac : str
+      AP mac
+    version : str
+      version
+    ip_address : str
+    mxtunnel_status : str{'up', 'down'}
+      MxTunnel status, up / down
+    mxedge_id : str
+      Mist Edge id, if AP is connecting to a Mist Edge
+    lldp_system_name : str
+      LLDP system name
+    lldp_system_desc : str
+      LLDP system description
+    lldp_port_id : str
+      LLDP port id
+    lldp_mgmt_addr : str
+      LLDP management ip address
+    page : int, default: 1
+    limit : int, default: 100
+    start : int
+    end : int
+    duration : str, default: 1d        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/devices/count"
     query_params={}
@@ -94,37 +134,46 @@ def countOrgDevices(mist_session:_APISession, org_id:str, distinct:str, hostname
     resp = mist_session.mist_get(uri=uri, query=query_params)
     return resp
     
-def countOrgDevicesEvents(mist_session:_APISession, org_id:str, distinct:str, site_id:str=None, ap:str=None, apfw:str=None, model:str=None, text:str=None, timestamp:str=None, type:str=None, page:int=1, limit:int=100, start:int=None, end:int=None, duration:str="1d") -> _APIResponse:
+def countOrgDeviceEvents(mist_session:_APISession, org_id:str, distinct:str, site_id:str=None, ap:str=None, apfw:str=None, model:str=None, text:str=None, timestamp:str=None, type:str=None, page:int=1, limit:int=100, start:int=None, end:int=None, duration:str="1d") -> _APIResponse:
     """
-    API doc: https://doc.mist-lab.fr/#operation/countOrgDevicesEvents
+    API doc: https://doc.mist-lab.fr/#operation/countOrgDeviceEvents
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id        
+    org_id : str        
     
     QUERY PARAMS
     ------------
-    :param str distinct(org_id, site_id, ap, apfw, model, text, timestamp, type)
-    :param str site_id - site id
-    :param str ap - AP mac
-    :param str apfw - AP Firmware
-    :param str model - device model
-    :param str text - event message
-    :param str timestamp - event time
-    :param str type - Events Type
-    :param int page
-    :param int limit
-    :param int start
-    :param int end
-    :param str duration        
+    distinct : str{'org_id', 'site_id', 'ap', 'apfw', 'model', 'text', 'timestamp', 'type'}, default: model
+    site_id : str
+      site id
+    ap : str
+      AP mac
+    apfw : str
+      AP Firmware
+    model : str
+      device model
+    text : str
+      event message
+    timestamp : str
+      event time
+    type : str
+      Events Type
+    page : int, default: 1
+    limit : int, default: 100
+    start : int
+    end : int
+    duration : str, default: 1d        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/devices/events/count"
     query_params={}
@@ -144,41 +193,54 @@ def countOrgDevicesEvents(mist_session:_APISession, org_id:str, distinct:str, si
     resp = mist_session.mist_get(uri=uri, query=query_params)
     return resp
     
-def searchOrgDevicesEvents(mist_session:_APISession, org_id:str, mac:str=None, model:str=None, text:str=None, timestamp:str=None, type:str=None, limit:int=100, start:int=None, end:int=None, duration:str="1d") -> _APIResponse:
+def searchOrgDeviceEvents(mist_session:_APISession, org_id:str, mac:str=None, model:str=None, device_type:str="ap", text:str=None, timestamp:str=None, type:str=None, last_by:str=None, limit:int=100, start:int=None, end:int=None, duration:str="1d") -> _APIResponse:
     """
-    API doc: https://doc.mist-lab.fr/#operation/searchOrgDevicesEvents
+    API doc: https://doc.mist-lab.fr/#operation/searchOrgDeviceEvents
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id        
+    org_id : str        
     
     QUERY PARAMS
     ------------
-    :param str mac - device mac
-    :param str model - device model
-    :param str text - event message
-    :param str timestamp - event time
-    :param str type - see [Event Types Definition](/#tag/Constants/operation/getDeviceEventsDefinitions)
-    :param int limit
-    :param int start
-    :param int end
-    :param str duration        
+    mac : str
+      device mac
+    model : str
+      device model
+    device_type : str{'ap', 'switch', 'gateway'}, default: ap
+      device type
+    text : str
+      event message
+    timestamp : str
+      event time
+    type : str
+      see [listDeviceEventsDefinitions](/#operation/listDeviceEventsDefinitions)
+    last_by : str
+      Return last/recent event for passed in field
+    limit : int, default: 100
+    start : int
+    end : int
+    duration : str, default: 1d        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/devices/events/search"
     query_params={}
     if mac: query_params["mac"]=mac
     if model: query_params["model"]=model
+    if device_type: query_params["device_type"]=device_type
     if text: query_params["text"]=text
     if timestamp: query_params["timestamp"]=timestamp
     if type: query_params["type"]=type
+    if last_by: query_params["last_by"]=last_by
     if limit: query_params["limit"]=limit
     if start: query_params["start"]=start
     if end: query_params["end"]=end
@@ -192,23 +254,25 @@ def countOrgDeviceLastConfigs(mist_session:_APISession, org_id:str, device_type:
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id        
+    org_id : str        
     
     QUERY PARAMS
     ------------
-    :param str device_type(ap, switch, gateway)
-    :param str distinct(mac, version, name, site_id)
-    :param int start
-    :param int end
-    :param int limit        
+    device_type : str{'ap', 'switch', 'gateway'}, default: ap
+    distinct : str{'mac', 'version', 'name', 'site_id'}
+    start : int
+    end : int
+    limit : int, default: 100        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/devices/last_config/count"
     query_params={}
@@ -226,26 +290,28 @@ def searchOrgDeviceLastConfigs(mist_session:_APISession, org_id:str, device_type
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id        
+    org_id : str        
     
     QUERY PARAMS
     ------------
-    :param str device_type(ap, switch, gateway)
-    :param str mac
-    :param str name
-    :param str version
-    :param int start
-    :param int end
-    :param int limit
-    :param str duration        
+    device_type : str{'ap', 'switch', 'gateway'}, default: ap
+    mac : str
+    name : str
+    version : str
+    start : int
+    end : int
+    limit : int, default: 100
+    duration : str, default: 1d        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/devices/last_config/search"
     query_params={}
@@ -260,24 +326,64 @@ def searchOrgDeviceLastConfigs(mist_session:_APISession, org_id:str, device_type
     resp = mist_session.mist_get(uri=uri, query=query_params)
     return resp
     
-def getOrgApsMacs(mist_session:_APISession, org_id:str) -> _APIResponse:
+@deprecation.deprecated(deprecated_in="0.37.7", removed_in="0.52.0", current_version="0.46.1", details="function replaced with listOrgApsMacs")  
+def getOrgApsMacs(mist_session:_APISession, org_id:str, page:int=1, limit:int=100) -> _APIResponse:
     """
-    API doc: https://doc.mist-lab.fr/#operation/getOrgApsMacs
+    API doc: https://doc.mist-lab.fr/#operation/listOrgApsMacs
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id        
+    org_id : str        
+    
+    QUERY PARAMS
+    ------------
+    page : int, default: 1
+    limit : int, default: 100        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/devices/radio_macs"
     query_params={}
+    if page: query_params["page"]=page
+    if limit: query_params["limit"]=limit
+    resp = mist_session.mist_get(uri=uri, query=query_params)
+    return resp
+    
+def listOrgApsMacs(mist_session:_APISession, org_id:str, page:int=1, limit:int=100) -> _APIResponse:
+    """
+    API doc: https://doc.mist-lab.fr/#operation/listOrgApsMacs
+    
+    PARAMS
+    -----------
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
+    
+    PATH PARAMS
+    -----------
+    org_id : str        
+    
+    QUERY PARAMS
+    ------------
+    page : int, default: 1
+    limit : int, default: 100        
+    
+    RETURN
+    -----------
+    mistapi.APIResponse
+        response from the API call
+    """
+    uri = f"/api/v1/orgs/{org_id}/devices/radio_macs"
+    query_params={}
+    if page: query_params["page"]=page
+    if limit: query_params["limit"]=limit
     resp = mist_session.mist_get(uri=uri, query=query_params)
     return resp
     
@@ -287,42 +393,63 @@ def searchOrgDevices(mist_session:_APISession, org_id:str, hostname:str=None, si
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id        
+    org_id : str        
     
     QUERY PARAMS
     ------------
-    :param str hostname - partial / full hostname
-    :param str site_id - site id
-    :param str model - device model
-    :param str mac - AP mac
-    :param str version - version
-    :param bool power_constrained - power_constrained
-    :param str ip_address
-    :param str mxtunnel_status(up, down) - MxTunnel status, up / down
-    :param str mxedge_id - Mist Edge id, if AP is connecting to a Mist Edge
-    :param str lldp_system_name - LLDP system name
-    :param str lldp_system_desc - LLDP system description
-    :param str lldp_port_id - LLDP port id
-    :param str lldp_mgmt_addr - LLDP management ip address
-    :param int band_24_bandwith - Bandwith of band_24
-    :param int band_5_bandwith - Bandwith of band_5
-    :param int band_6_bandwith - Bandwith of band_6
-    :param int band_24_channel - Channel of band_24
-    :param int band_5_channel - Channel of band_5
-    :param int band_6_channel - Channel of band_6
-    :param int eth0_port_speed - Port speed of eth0
-    :param int limit
-    :param int start
-    :param int end
-    :param str duration        
+    hostname : str
+      partial / full hostname
+    site_id : str
+      site id
+    model : str
+      device model
+    mac : str
+      AP mac
+    version : str
+      version
+    power_constrained : bool
+      power_constrained
+    ip_address : str
+    mxtunnel_status : str{'up', 'down'}
+      MxTunnel status, up / down
+    mxedge_id : str
+      Mist Edge id, if AP is connecting to a Mist Edge
+    lldp_system_name : str
+      LLDP system name
+    lldp_system_desc : str
+      LLDP system description
+    lldp_port_id : str
+      LLDP port id
+    lldp_mgmt_addr : str
+      LLDP management ip address
+    band_24_bandwith : int
+      Bandwith of band_24
+    band_5_bandwith : int
+      Bandwith of band_5
+    band_6_bandwith : int
+      Bandwith of band_6
+    band_24_channel : int
+      Channel of band_24
+    band_5_channel : int
+      Channel of band_5
+    band_6_channel : int
+      Channel of band_6
+    eth0_port_speed : int
+      Port speed of eth0
+    limit : int, default: 100
+    start : int
+    end : int
+    duration : str, default: 1d        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/devices/search"
     query_params={}
@@ -353,21 +480,47 @@ def searchOrgDevices(mist_session:_APISession, org_id:str, hostname:str=None, si
     resp = mist_session.mist_get(uri=uri, query=query_params)
     return resp
     
+@deprecation.deprecated(deprecated_in="0.37.7", removed_in="0.52.0", current_version="0.46.1", details="function replaced with listOrgMultiSitesDevicesUpgrades")  
 def getOrgMultiSitesDevicesUpgrades(mist_session:_APISession, org_id:str) -> _APIResponse:
     """
-    API doc: https://doc.mist-lab.fr/#operation/getOrgMultiSitesDevicesUpgrades
+    API doc: https://doc.mist-lab.fr/#operation/listOrgMultiSitesDevicesUpgrades
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id        
+    org_id : str        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
+    """
+    uri = f"/api/v1/orgs/{org_id}/devices/upgrade"
+    query_params={}
+    resp = mist_session.mist_get(uri=uri, query=query_params)
+    return resp
+    
+def listOrgMultiSitesDevicesUpgrades(mist_session:_APISession, org_id:str) -> _APIResponse:
+    """
+    API doc: https://doc.mist-lab.fr/#operation/listOrgMultiSitesDevicesUpgrades
+    
+    PARAMS
+    -----------
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
+    
+    PATH PARAMS
+    -----------
+    org_id : str        
+    
+    RETURN
+    -----------
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/devices/upgrade"
     query_params={}
@@ -380,15 +533,22 @@ def upgradeOrgMultiSitesDevices(mist_session:_APISession, org_id:str, body:objec
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id        
+    org_id : str        
+    
+    BODY PARAMS
+    -----------
+    body : dict
+        JSON object to send to Mist Cloud (see API doc above for more details)
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/devices/upgrade"
     resp = mist_session.mist_post(uri=uri, body=body)
@@ -400,16 +560,18 @@ def getOrgMultiSitesUpgrade(mist_session:_APISession, org_id:str, upgrade_id:str
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id
-    :param str upgrade_id        
+    org_id : str
+    upgrade_id : str        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/devices/upgrade/{upgrade_id}"
     query_params={}
