@@ -12,39 +12,49 @@
 
 from mistapi import APISession as _APISession
 from mistapi.__api_response import APIResponse as _APIResponse
+import deprecation
 
-def getOrgLogs(mist_session:_APISession, org_id:str, site_id:str=None, admin_name:str=None, message:str=None, start:int=None, end:int=None, limit:int=100, page:int=1, duration:str="1d") -> _APIResponse:
+@deprecation.deprecated(deprecated_in="0.37.7", removed_in="0.52.0", current_version="0.46.1", details="function replaced with listOrgLogs")  
+def getOrgLogs(mist_session:_APISession, org_id:str, site_id:str=None, admin_name:str=None, message:str=None, sort:str=None, start:int=None, end:int=None, limit:int=100, page:int=1, duration:str="1d") -> _APIResponse:
     """
-    API doc: https://doc.mist-lab.fr/#operation/getOrgLogs
+    API doc: https://doc.mist-lab.fr/#operation/listOrgLogs
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id        
+    org_id : str        
     
     QUERY PARAMS
     ------------
-    :param str site_id - site id
-    :param str admin_name - admin name or email
-    :param str message - message
-    :param int start
-    :param int end
-    :param int limit
-    :param int page
-    :param str duration        
+    site_id : str
+      site id
+    admin_name : str
+      admin name or email
+    message : str
+      message
+    sort : str{'timestamp', '-timestamp', 'site_id', 'admin_id'}
+      sort order
+    start : int
+    end : int
+    limit : int, default: 100
+    page : int, default: 1
+    duration : str, default: 1d        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/logs"
     query_params={}
     if site_id: query_params["site_id"]=site_id
     if admin_name: query_params["admin_name"]=admin_name
     if message: query_params["message"]=message
+    if sort: query_params["sort"]=sort
     if start: query_params["start"]=start
     if end: query_params["end"]=end
     if limit: query_params["limit"]=limit
@@ -53,34 +63,84 @@ def getOrgLogs(mist_session:_APISession, org_id:str, site_id:str=None, admin_nam
     resp = mist_session.mist_get(uri=uri, query=query_params)
     return resp
     
-def countOrgLogsByDistinctAttributes(mist_session:_APISession, org_id:str, distinct:str, admin_id:str=None, admin_name:str=None, site_id:str=None, message:str=None, page:int=1, limit:int=100, start:int=None, end:int=None, duration:str="1d") -> _APIResponse:
+def listOrgLogs(mist_session:_APISession, org_id:str, site_id:str=None, admin_name:str=None, message:str=None, sort:str=None, start:int=None, end:int=None, limit:int=100, page:int=1, duration:str="1d") -> _APIResponse:
     """
-    API doc: https://doc.mist-lab.fr/#operation/countOrgLogsByDistinctAttributes
+    API doc: https://doc.mist-lab.fr/#operation/listOrgLogs
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id        
+    org_id : str        
     
     QUERY PARAMS
     ------------
-    :param str distinct(admin_id, admin_name, message, site_id)
-    :param str admin_id
-    :param str admin_name
-    :param str site_id
-    :param str message
-    :param int page
-    :param int limit
-    :param int start
-    :param int end
-    :param str duration        
+    site_id : str
+      site id
+    admin_name : str
+      admin name or email
+    message : str
+      message
+    sort : str{'timestamp', '-timestamp', 'site_id', 'admin_id'}
+      sort order
+    start : int
+    end : int
+    limit : int, default: 100
+    page : int, default: 1
+    duration : str, default: 1d        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
+    """
+    uri = f"/api/v1/orgs/{org_id}/logs"
+    query_params={}
+    if site_id: query_params["site_id"]=site_id
+    if admin_name: query_params["admin_name"]=admin_name
+    if message: query_params["message"]=message
+    if sort: query_params["sort"]=sort
+    if start: query_params["start"]=start
+    if end: query_params["end"]=end
+    if limit: query_params["limit"]=limit
+    if page: query_params["page"]=page
+    if duration: query_params["duration"]=duration
+    resp = mist_session.mist_get(uri=uri, query=query_params)
+    return resp
+    
+def countOrgLogs(mist_session:_APISession, org_id:str, distinct:str, admin_id:str=None, admin_name:str=None, site_id:str=None, message:str=None, page:int=1, limit:int=100, start:int=None, end:int=None, duration:str="1d") -> _APIResponse:
+    """
+    API doc: https://doc.mist-lab.fr/#operation/countOrgLogs
+    
+    PARAMS
+    -----------
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
+    
+    PATH PARAMS
+    -----------
+    org_id : str        
+    
+    QUERY PARAMS
+    ------------
+    distinct : str{'admin_id', 'admin_name', 'message', 'site_id'}, default: admin_name
+    admin_id : str
+    admin_name : str
+    site_id : str
+    message : str
+    page : int, default: 1
+    limit : int, default: 100
+    start : int
+    end : int
+    duration : str, default: 1d        
+    
+    RETURN
+    -----------
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/logs/count"
     query_params={}
