@@ -12,6 +12,7 @@
 
 from mistapi import APISession as _APISession
 from mistapi.__api_response import APIResponse as _APIResponse
+import deprecation
 
 def getOrgStats(mist_session:_APISession, org_id:str, page:int=1, limit:int=100, start:int=None, end:int=None, duration:str="1d") -> _APIResponse:
     """
@@ -19,23 +20,25 @@ def getOrgStats(mist_session:_APISession, org_id:str, page:int=1, limit:int=100,
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id        
+    org_id : str        
     
     QUERY PARAMS
     ------------
-    :param int page
-    :param int limit
-    :param int start
-    :param int end
-    :param str duration        
+    page : int, default: 1
+    limit : int, default: 100
+    start : int
+    end : int
+    duration : str, default: 1d        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/stats"
     query_params={}
@@ -47,29 +50,68 @@ def getOrgStats(mist_session:_APISession, org_id:str, page:int=1, limit:int=100,
     resp = mist_session.mist_get(uri=uri, query=query_params)
     return resp
     
+@deprecation.deprecated(deprecated_in="0.37.7", removed_in="0.52.0", current_version="0.46.1", details="function replaced with listOrgAssetsStats")  
 def getOrgAssetsStats(mist_session:_APISession, org_id:str, page:int=1, limit:int=100, start:int=None, end:int=None, duration:str="1d") -> _APIResponse:
     """
-    API doc: https://doc.mist-lab.fr/#operation/getOrgAssetsStats
+    API doc: https://doc.mist-lab.fr/#operation/listOrgAssetsStats
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id        
+    org_id : str        
     
     QUERY PARAMS
     ------------
-    :param int page
-    :param int limit
-    :param int start
-    :param int end
-    :param str duration        
+    page : int, default: 1
+    limit : int, default: 100
+    start : int
+    end : int
+    duration : str, default: 1d        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
+    """
+    uri = f"/api/v1/orgs/{org_id}/stats/assets"
+    query_params={}
+    if page: query_params["page"]=page
+    if limit: query_params["limit"]=limit
+    if start: query_params["start"]=start
+    if end: query_params["end"]=end
+    if duration: query_params["duration"]=duration
+    resp = mist_session.mist_get(uri=uri, query=query_params)
+    return resp
+    
+def listOrgAssetsStats(mist_session:_APISession, org_id:str, page:int=1, limit:int=100, start:int=None, end:int=None, duration:str="1d") -> _APIResponse:
+    """
+    API doc: https://doc.mist-lab.fr/#operation/listOrgAssetsStats
+    
+    PARAMS
+    -----------
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
+    
+    PATH PARAMS
+    -----------
+    org_id : str        
+    
+    QUERY PARAMS
+    ------------
+    page : int, default: 1
+    limit : int, default: 100
+    start : int
+    end : int
+    duration : str, default: 1d        
+    
+    RETURN
+    -----------
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/stats/assets"
     query_params={}
@@ -87,19 +129,21 @@ def countOrgAssetsByDistanceField(mist_session:_APISession, org_id:str, distinct
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id        
+    org_id : str        
     
     QUERY PARAMS
     ------------
-    :param str distinct(site_id, mac, map_id, ibeacon_uuid, ibeacon_major, ibeacon_minor)        
+    distinct : str{'site_id', 'mac', 'map_id', 'ibeacon_uuid', 'ibeacon_major', 'ibeacon_minor'}        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/stats/assets/count"
     query_params={}
@@ -113,36 +157,38 @@ def searchOrgAssets(mist_session:_APISession, org_id:str, site_id:str=None, mac:
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id        
+    org_id : str        
     
     QUERY PARAMS
     ------------
-    :param str site_id
-    :param str mac
-    :param str device_name
-    :param str name
-    :param str map_id
-    :param str ibeacon_uuid
-    :param str ibeacon_major
-    :param str ibeacon_minor
-    :param str eddystone_uid_namespace
-    :param str eddystone_uid_instance
-    :param str eddystone_url
-    :param str ap_mac
-    :param int beam
-    :param int rssi
-    :param int limit
-    :param int start
-    :param int end
-    :param str duration        
+    site_id : str
+    mac : str
+    device_name : str
+    name : str
+    map_id : str
+    ibeacon_uuid : str
+    ibeacon_major : str
+    ibeacon_minor : str
+    eddystone_uid_namespace : str
+    eddystone_uid_instance : str
+    eddystone_url : str
+    ap_mac : str
+    beam : int
+    rssi : int
+    limit : int, default: 100
+    start : int
+    end : int
+    duration : str, default: 1d        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/stats/assets/search"
     query_params={}
@@ -173,15 +219,17 @@ def countOrgBgpStats(mist_session:_APISession, org_id:str) -> _APIResponse:
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id        
+    org_id : str        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/stats/bgp_peers/count"
     query_params={}
@@ -194,91 +242,195 @@ def searchOrgBgpStats(mist_session:_APISession, org_id:str) -> _APIResponse:
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id        
+    org_id : str        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/stats/bgp_peers/search"
     query_params={}
     resp = mist_session.mist_get(uri=uri, query=query_params)
     return resp
     
-def getOrgDevicesStats(mist_session:_APISession, org_id:str, page:int=1, limit:int=100, start:int=None, end:int=None, duration:str="1d", type:str="ap", status:str="all", site_id:str=None, mac:str=None, evpntopo_id:str=None, evpn_unused:str=None) -> _APIResponse:
+@deprecation.deprecated(deprecated_in="0.37.7", removed_in="0.52.0", current_version="0.46.1", details="function replaced with listOrgDevicesStats")  
+def getOrgDevicesStats(mist_session:_APISession, org_id:str, type:str="ap", status:str="all", site_id:str=None, mac:str=None, evpntopo_id:str=None, evpn_unused:str=None, fields:str=None, page:int=1, limit:int=100, start:int=None, end:int=None, duration:str="1d") -> _APIResponse:
     """
-    API doc: https://doc.mist-lab.fr/#operation/getOrgDevicesStats
+    API doc: https://doc.mist-lab.fr/#operation/listOrgDevicesStats
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id        
+    org_id : str        
     
     QUERY PARAMS
     ------------
-    :param int page
-    :param int limit
-    :param int start
-    :param int end
-    :param str duration
-    :param str type(ap, switch, gateways, all)
-    :param str status(all, connected, disconnected)
-    :param str site_id
-    :param str mac
-    :param str evpntopo_id - EVPN Topology ID
-    :param str evpn_unused - if `evpn_unused`==`true`, find EVPN eligible switches which don’t belong to any EVPN Topology yet        
+    type : str{'ap', 'switch', 'gateway', 'all'}, default: ap
+    status : str{'all', 'connected', 'disconnected'}, default: all
+    site_id : str
+    mac : str
+    evpntopo_id : str
+      EVPN Topology ID
+    evpn_unused : str
+      if `evpn_unused`==`true`, find EVPN eligible switches which don’t belong to any EVPN Topology yet
+    fields : str
+    page : int, default: 1
+    limit : int, default: 100
+    start : int
+    end : int
+    duration : str, default: 1d        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/stats/devices"
     query_params={}
-    if page: query_params["page"]=page
-    if limit: query_params["limit"]=limit
-    if start: query_params["start"]=start
-    if end: query_params["end"]=end
-    if duration: query_params["duration"]=duration
     if type: query_params["type"]=type
     if status: query_params["status"]=status
     if site_id: query_params["site_id"]=site_id
     if mac: query_params["mac"]=mac
     if evpntopo_id: query_params["evpntopo_id"]=evpntopo_id
     if evpn_unused: query_params["evpn_unused"]=evpn_unused
+    if fields: query_params["fields"]=fields
+    if page: query_params["page"]=page
+    if limit: query_params["limit"]=limit
+    if start: query_params["start"]=start
+    if end: query_params["end"]=end
+    if duration: query_params["duration"]=duration
     resp = mist_session.mist_get(uri=uri, query=query_params)
     return resp
     
-def getOrgMxEdgesStats(mist_session:_APISession, org_id:str, page:int=1, limit:int=100, start:int=None, end:int=None, duration:str="1d", for_site:str="false") -> _APIResponse:
+def listOrgDevicesStats(mist_session:_APISession, org_id:str, type:str="ap", status:str="all", site_id:str=None, mac:str=None, evpntopo_id:str=None, evpn_unused:str=None, fields:str=None, page:int=1, limit:int=100, start:int=None, end:int=None, duration:str="1d") -> _APIResponse:
     """
-    API doc: https://doc.mist-lab.fr/#operation/getOrgMxEdgesStats
+    API doc: https://doc.mist-lab.fr/#operation/listOrgDevicesStats
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id        
+    org_id : str        
     
     QUERY PARAMS
     ------------
-    :param int page
-    :param int limit
-    :param int start
-    :param int end
-    :param str duration
-    :param str for_site(true, false, any) - filter for site level mist edges        
+    type : str{'ap', 'switch', 'gateway', 'all'}, default: ap
+    status : str{'all', 'connected', 'disconnected'}, default: all
+    site_id : str
+    mac : str
+    evpntopo_id : str
+      EVPN Topology ID
+    evpn_unused : str
+      if `evpn_unused`==`true`, find EVPN eligible switches which don’t belong to any EVPN Topology yet
+    fields : str
+    page : int, default: 1
+    limit : int, default: 100
+    start : int
+    end : int
+    duration : str, default: 1d        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
+    """
+    uri = f"/api/v1/orgs/{org_id}/stats/devices"
+    query_params={}
+    if type: query_params["type"]=type
+    if status: query_params["status"]=status
+    if site_id: query_params["site_id"]=site_id
+    if mac: query_params["mac"]=mac
+    if evpntopo_id: query_params["evpntopo_id"]=evpntopo_id
+    if evpn_unused: query_params["evpn_unused"]=evpn_unused
+    if fields: query_params["fields"]=fields
+    if page: query_params["page"]=page
+    if limit: query_params["limit"]=limit
+    if start: query_params["start"]=start
+    if end: query_params["end"]=end
+    if duration: query_params["duration"]=duration
+    resp = mist_session.mist_get(uri=uri, query=query_params)
+    return resp
+    
+@deprecation.deprecated(deprecated_in="0.37.7", removed_in="0.52.0", current_version="0.46.1", details="function replaced with listOrgMxEdgesStats")  
+def getOrgMxEdgesStats(mist_session:_APISession, org_id:str, page:int=1, limit:int=100, start:int=None, end:int=None, duration:str="1d", for_site:str="false") -> _APIResponse:
+    """
+    API doc: https://doc.mist-lab.fr/#operation/listOrgMxEdgesStats
+    
+    PARAMS
+    -----------
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
+    
+    PATH PARAMS
+    -----------
+    org_id : str        
+    
+    QUERY PARAMS
+    ------------
+    page : int, default: 1
+    limit : int, default: 100
+    start : int
+    end : int
+    duration : str, default: 1d
+    for_site : str{'true', 'false', 'any'}, default: false
+      filter for site level mist edges        
+    
+    RETURN
+    -----------
+    mistapi.APIResponse
+        response from the API call
+    """
+    uri = f"/api/v1/orgs/{org_id}/stats/mxedges"
+    query_params={}
+    if page: query_params["page"]=page
+    if limit: query_params["limit"]=limit
+    if start: query_params["start"]=start
+    if end: query_params["end"]=end
+    if duration: query_params["duration"]=duration
+    if for_site: query_params["for_site"]=for_site
+    resp = mist_session.mist_get(uri=uri, query=query_params)
+    return resp
+    
+def listOrgMxEdgesStats(mist_session:_APISession, org_id:str, page:int=1, limit:int=100, start:int=None, end:int=None, duration:str="1d", for_site:str="false") -> _APIResponse:
+    """
+    API doc: https://doc.mist-lab.fr/#operation/listOrgMxEdgesStats
+    
+    PARAMS
+    -----------
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
+    
+    PATH PARAMS
+    -----------
+    org_id : str        
+    
+    QUERY PARAMS
+    ------------
+    page : int, default: 1
+    limit : int, default: 100
+    start : int
+    end : int
+    duration : str, default: 1d
+    for_site : str{'true', 'false', 'any'}, default: false
+      filter for site level mist edges        
+    
+    RETURN
+    -----------
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/stats/mxedges"
     query_params={}
@@ -297,16 +449,18 @@ def getOrgMxEdgeStats(mist_session:_APISession, org_id:str, mxedge_id:str) -> _A
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id
-    :param str mxedge_id        
+    org_id : str
+    mxedge_id : str        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/stats/mxedges/{mxedge_id}"
     query_params={}
@@ -319,16 +473,18 @@ def getOrgOtherDeviceStats(mist_session:_APISession, org_id:str, device_mac:str)
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id
-    :param str device_mac        
+    org_id : str
+    device_mac : str        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/stats/otherdevices/{device_mac}"
     query_params={}
@@ -341,51 +497,82 @@ def searchOrgSwOrGwPorts(mist_session:_APISession, org_id:str, full_duplex:bool=
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id        
+    org_id : str        
     
     QUERY PARAMS
     ------------
-    :param bool full_duplex - indicates full or half duplex
-    :param str mac - device identifier
-    :param str neighbor_mac - Chassis identifier of the chassis type listed
-    :param str neighbor_port_desc - Description supplied by the system on the interface E.g. “GigabitEthernet2/0/39”
-    :param str neighbor_system_name - Name supplied by the system on the interface E.g. neighbor system name E.g. “Kumar-Acc-SW.mist.local”
-    :param bool poe_disabled - is the POE configured not be disabled.
-    :param str poe_mode - poe mode depending on class E.g. “802.3at”
-    :param bool poe_on - is the device attached to POE
-    :param str port_id - interface name
-    :param str port_mac - interface mac address
-    :param float power_draw - Amount of power being used by the interface at the time the command is executed. Unit in watts.
-    :param int tx_pkts - Output packets
-    :param int rx_pkts - Input packets
-    :param int rx_bytes - Input bytes
-    :param int tx_bps - Output rate
-    :param int rx_bps - Input rate
-    :param int tx_errors - Output errors
-    :param int rx_errors - Input errors
-    :param int tx_mcast_pkts - Multicast output packets
-    :param int tx_bcast_pkts - Broadcast output packets
-    :param int rx_mcast_pkts - Multicast input packets
-    :param int rx_bcast_pkts - Broadcast input packets
-    :param int speed - port speed
-    :param int mac_limit - Limit on number of dynamically learned macs
-    :param int mac_count - Number of mac addresses in the forwarding table
-    :param bool up - indicates if interface is up
-    :param str stp_state(forwarding, blocking, learning, listening, disabled) - if `up`==`true`
-    :param str stp_role(designated, backup, alternate, root, root-prevented) - if `up`==`true`
-    :param str auth_state(init, authenticated, authenticating, held) - if `up`==`true` && has Authenticator role
-    :param int limit
-    :param int start
-    :param int end
-    :param str duration        
+    full_duplex : bool
+      indicates full or half duplex
+    mac : str
+      device identifier
+    neighbor_mac : str
+      Chassis identifier of the chassis type listed
+    neighbor_port_desc : str
+      Description supplied by the system on the interface E.g. “GigabitEthernet2/0/39”
+    neighbor_system_name : str
+      Name supplied by the system on the interface E.g. neighbor system name E.g. “Kumar-Acc-SW.mist.local”
+    poe_disabled : bool
+      is the POE configured not be disabled.
+    poe_mode : str
+      poe mode depending on class E.g. “802.3at”
+    poe_on : bool
+      is the device attached to POE
+    port_id : str
+      interface name
+    port_mac : str
+      interface mac address
+    power_draw : float
+      Amount of power being used by the interface at the time the command is executed. Unit in watts.
+    tx_pkts : int
+      Output packets
+    rx_pkts : int
+      Input packets
+    rx_bytes : int
+      Input bytes
+    tx_bps : int
+      Output rate
+    rx_bps : int
+      Input rate
+    tx_errors : int
+      Output errors
+    rx_errors : int
+      Input errors
+    tx_mcast_pkts : int
+      Multicast output packets
+    tx_bcast_pkts : int
+      Broadcast output packets
+    rx_mcast_pkts : int
+      Multicast input packets
+    rx_bcast_pkts : int
+      Broadcast input packets
+    speed : int
+      port speed
+    mac_limit : int
+      Limit on number of dynamically learned macs
+    mac_count : int
+      Number of mac addresses in the forwarding table
+    up : bool
+      indicates if interface is up
+    stp_state : str{'forwarding', 'blocking', 'learning', 'listening', 'disabled'}
+      if `up`==`true`
+    stp_role : str{'designated', 'backup', 'alternate', 'root', 'root-prevented'}
+      if `up`==`true`
+    auth_state : str{'init', 'authenticated', 'authenticating', 'held'}
+      if `up`==`true` && has Authenticator role
+    limit : int, default: 100
+    start : int
+    end : int
+    duration : str, default: 1d        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/stats/ports/search"
     query_params={}
@@ -425,55 +612,83 @@ def searchOrgSwOrGwPorts(mist_session:_APISession, org_id:str, full_duplex:bool=
     resp = mist_session.mist_get(uri=uri, query=query_params)
     return resp
     
-def countOrgByDisctinctAttributesOfSwitchPorts(mist_session:_APISession, org_id:str, distinct:str="mac", full_duplex:bool=None, mac:str=None, neighbor_mac:str=None, neighbor_port_desc:str=None, neighbor_system_name:str=None, poe_disabled:bool=None, poe_mode:str=None, poe_on:bool=None, port_id:str=None, port_mac:str=None, power_draw:float=None, tx_pkts:int=None, rx_pkts:int=None, rx_bytes:int=None, tx_bps:int=None, rx_bps:int=None, tx_mcast_pkts:int=None, tx_bcast_pkts:int=None, rx_mcast_pkts:int=None, rx_bcast_pkts:int=None, speed:int=None, stp_state:str=None, stp_role:str=None, auth_state:str=None, up:bool=None, page:int=1, limit:int=100, start:int=None, end:int=None, duration:str="1d") -> _APIResponse:
+def countOrgSwitchPorts(mist_session:_APISession, org_id:str, distinct:str="mac", full_duplex:bool=None, mac:str=None, neighbor_mac:str=None, neighbor_port_desc:str=None, neighbor_system_name:str=None, poe_disabled:bool=None, poe_mode:str=None, poe_on:bool=None, port_id:str=None, port_mac:str=None, power_draw:float=None, tx_pkts:int=None, rx_pkts:int=None, rx_bytes:int=None, tx_bps:int=None, rx_bps:int=None, tx_mcast_pkts:int=None, tx_bcast_pkts:int=None, rx_mcast_pkts:int=None, rx_bcast_pkts:int=None, speed:int=None, stp_state:str=None, stp_role:str=None, auth_state:str=None, up:bool=None, page:int=1, limit:int=100, start:int=None, end:int=None, duration:str="1d") -> _APIResponse:
     """
-    API doc: https://doc.mist-lab.fr/#operation/countOrgByDisctinctAttributesOfSwitchPorts
+    API doc: https://doc.mist-lab.fr/#operation/countOrgSwitchPorts
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id        
+    org_id : str        
     
     QUERY PARAMS
     ------------
-    :param str distinct(port_id, port_mac, full_duplex, mac, neighbor_mac, neighbor_port_desc, neighbor_system_name, poe_disabled, poe_mode, poe_on, speed, up) - port_id, port_mac, full_duplex, mac, neighbor_macneighbor_port_desc, neighbor_system_name, poe_disabled, poe_mode, poe_on, speed, up
-    :param bool full_duplex - indicates full or half duplex
-    :param str mac - device identifier
-    :param str neighbor_mac - Chassis identifier of the chassis type listed
-    :param str neighbor_port_desc - Description supplied by the system on the interface E.g. “GigabitEthernet2/0/39”
-    :param str neighbor_system_name - Name supplied by the system on the interface E.g. neighbor system name E.g. “Kumar-Acc-SW.mist.local”
-    :param bool poe_disabled - is the POE configured not be disabled.
-    :param str poe_mode - poe mode depending on class E.g. “802.3at”
-    :param bool poe_on - is the device attached to POE
-    :param str port_id - interface name
-    :param str port_mac - interface mac address
-    :param float power_draw - Amount of power being used by the interface at the time the command is executed. Unit in watts.
-    :param int tx_pkts - Output packets
-    :param int rx_pkts - Input packets
-    :param int rx_bytes - Input bytes
-    :param int tx_bps - Output rate
-    :param int rx_bps - Input rate
-    :param int tx_mcast_pkts - Multicast output packets
-    :param int tx_bcast_pkts - Broadcast output packets
-    :param int rx_mcast_pkts - Multicast input packets
-    :param int rx_bcast_pkts - Broadcast input packets
-    :param int speed - port speed
-    :param str stp_state(forwarding, blocking, learning, listening, disabled) - if `up`==`true`
-    :param str stp_role(designated, backup, alternate, root, root-prevented) - if `up`==`true`
-    :param str auth_state(init, authenticated, authenticating, held) - if `up`==`true`
-    :param bool up - indicates if interface is up
-    :param int page
-    :param int limit
-    :param int start
-    :param int end
-    :param str duration        
+    distinct : str{'port_id', 'port_mac', 'full_duplex', 'mac', 'neighbor_mac', 'neighbor_port_desc', 'neighbor_system_name', 'poe_disabled', 'poe_mode', 'poe_on', 'speed', 'up'}, default: mac
+      port_id, port_mac, full_duplex, mac, neighbor_macneighbor_port_desc, neighbor_system_name, poe_disabled, poe_mode, poe_on, speed, up
+    full_duplex : bool
+      indicates full or half duplex
+    mac : str
+      device identifier
+    neighbor_mac : str
+      Chassis identifier of the chassis type listed
+    neighbor_port_desc : str
+      Description supplied by the system on the interface E.g. “GigabitEthernet2/0/39”
+    neighbor_system_name : str
+      Name supplied by the system on the interface E.g. neighbor system name E.g. “Kumar-Acc-SW.mist.local”
+    poe_disabled : bool
+      is the POE configured not be disabled.
+    poe_mode : str
+      poe mode depending on class E.g. “802.3at”
+    poe_on : bool
+      is the device attached to POE
+    port_id : str
+      interface name
+    port_mac : str
+      interface mac address
+    power_draw : float
+      Amount of power being used by the interface at the time the command is executed. Unit in watts.
+    tx_pkts : int
+      Output packets
+    rx_pkts : int
+      Input packets
+    rx_bytes : int
+      Input bytes
+    tx_bps : int
+      Output rate
+    rx_bps : int
+      Input rate
+    tx_mcast_pkts : int
+      Multicast output packets
+    tx_bcast_pkts : int
+      Broadcast output packets
+    rx_mcast_pkts : int
+      Multicast input packets
+    rx_bcast_pkts : int
+      Broadcast input packets
+    speed : int
+      port speed
+    stp_state : str{'forwarding', 'blocking', 'learning', 'listening', 'disabled'}
+      if `up`==`true`
+    stp_role : str{'designated', 'backup', 'alternate', 'root', 'root-prevented'}
+      if `up`==`true`
+    auth_state : str{'init', 'authenticated', 'authenticating', 'held'}
+      if `up`==`true`
+    up : bool
+      indicates if interface is up
+    page : int, default: 1
+    limit : int, default: 100
+    start : int
+    end : int
+    duration : str, default: 1d        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/stats/switch_ports/count"
     query_params={}
@@ -517,21 +732,24 @@ def countOrgTunnelsStats(mist_session:_APISession, org_id:str, distinct:str=None
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id        
+    org_id : str        
     
     QUERY PARAMS
     ------------
-    :param str distinct(auth_algo) - - If `type`==`wxtunnel`: wxtunnel_id / ap / remote_ip / remote_port / state / mxedge_id / mxcluster_id / site_id / peer_mxedge_id; default is wxtunnel_id 
+    distinct : str{'auth_algo'}
+      - If `type`==`wxtunnel`: wxtunnel_id / ap / remote_ip / remote_port / state / mxedge_id / mxcluster_id / site_id / peer_mxedge_id; default is wxtunnel_id 
 - If `type`==`wan`: mac / site_id / node / peer_ip / peer_host/ ip / tunnel_name / protocol / auth_algo / encrypt_algo / ike_version / last_event / up
-    :param str type(wxtunnel, wan)        
+    type : str{'wxtunnel', 'wan'}, default: wxtunnel        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/stats/tunnels/count"
     query_params={}
@@ -546,38 +764,54 @@ def searchOrgTunnelsStats(mist_session:_APISession, org_id:str, mxcluster_id:str
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id        
+    org_id : str        
     
     QUERY PARAMS
     ------------
-    :param str mxcluster_id - if `type`==`wxtunnel`
-    :param str site_id
-    :param str wxtunnel_id - if `type`==`wxtunnel`
-    :param str ap - if `type`==`wxtunnel`
-    :param str mac - if `type`==`wan`
-    :param str node - if `type`==`wan`
-    :param str peer_ip - if `type`==`wan`
-    :param str peer_host - if `type`==`wan`
-    :param str ip - if `type`==`wan`
-    :param str tunnel_name - if `type`==`wan`
-    :param str protocol - if `type`==`wan`
-    :param str auth_algo - if `type`==`wan`
-    :param str encrypt_algo - if `type`==`wan`
-    :param str ike_version - if `type`==`wan`
-    :param str up - if `type`==`wan`
-    :param str type(wxtunnel, wan)
-    :param int limit
-    :param int start
-    :param int end
-    :param str duration        
+    mxcluster_id : str
+      if `type`==`wxtunnel`
+    site_id : str
+    wxtunnel_id : str
+      if `type`==`wxtunnel`
+    ap : str
+      if `type`==`wxtunnel`
+    mac : str
+      if `type`==`wan`
+    node : str
+      if `type`==`wan`
+    peer_ip : str
+      if `type`==`wan`
+    peer_host : str
+      if `type`==`wan`
+    ip : str
+      if `type`==`wan`
+    tunnel_name : str
+      if `type`==`wan`
+    protocol : str
+      if `type`==`wan`
+    auth_algo : str
+      if `type`==`wan`
+    encrypt_algo : str
+      if `type`==`wan`
+    ike_version : str
+      if `type`==`wan`
+    up : str
+      if `type`==`wan`
+    type : str{'wxtunnel', 'wan'}, default: wxtunnel
+    limit : int, default: 100
+    start : int
+    end : int
+    duration : str, default: 1d        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/stats/tunnels/search"
     query_params={}
@@ -610,24 +844,26 @@ def countOrgPeerPathStats(mist_session:_APISession, org_id:str, distinct:str=Non
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id        
+    org_id : str        
     
     QUERY PARAMS
     ------------
-    :param str distinct
-    :param int page
-    :param int limit
-    :param int start
-    :param int end
-    :param str duration        
+    distinct : str
+    page : int, default: 1
+    limit : int, default: 100
+    start : int
+    end : int
+    duration : str, default: 1d        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/stats/vpn_peers/count"
     query_params={}
@@ -646,22 +882,24 @@ def searchOrgPeerPathStats(mist_session:_APISession, org_id:str, start:int=None,
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id        
+    org_id : str        
     
     QUERY PARAMS
     ------------
-    :param int start
-    :param int end
-    :param str duration
-    :param int limit        
+    start : int
+    end : int
+    duration : str, default: 1d
+    limit : int, default: 100        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/stats/vpn_peers/search"
     query_params={}
