@@ -12,30 +12,36 @@
 
 from mistapi import APISession as _APISession
 from mistapi.__api_response import APIResponse as _APIResponse
+import deprecation
 
-def troubleshootOrgClient(mist_session:_APISession, org_id:str, mac:str=None, site_id:str=None, start:int=None, end:int=None, type:str=None) -> _APIResponse:
+def troubleshootOrg(mist_session:_APISession, org_id:str, mac:str=None, site_id:str=None, start:int=None, end:int=None, type:str=None) -> _APIResponse:
     """
-    API doc: https://doc.mist-lab.fr/#operation/troubleshootOrgClient
+    API doc: https://doc.mist-lab.fr/#operation/troubleshootOrg
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id        
+    org_id : str        
     
     QUERY PARAMS
     ------------
-    :param str mac - **required** when troubleshooting device
-    :param str site_id - **required** when troubleshooting site
-    :param int start
-    :param int end
-    :param str type(wireless, wired, wan) - when troubleshooting site, type of network to troubleshoot        
+    mac : str
+      **required** when troubleshooting device or a client
+    site_id : str
+      **required** when troubleshooting site
+    start : int
+    end : int
+    type : str{'wireless', 'wired', 'wan'}
+      when troubleshooting site, type of network to troubleshoot        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/troubleshoot"
     query_params={}
