@@ -12,31 +12,34 @@
 
 from mistapi import APISession as _APISession
 from mistapi.__api_response import APIResponse as _APIResponse
+import deprecation
 
-def countOrgClientsWired(mist_session:_APISession, org_id:str, distinct:str="mac", page:int=1, limit:int=100, start:int=None, end:int=None, duration:str="1d") -> _APIResponse:
+def countOrgWiredClients(mist_session:_APISession, org_id:str, distinct:str="mac", page:int=1, limit:int=100, start:int=None, end:int=None, duration:str="1d") -> _APIResponse:
     """
-    API doc: https://doc.mist-lab.fr/#operation/countOrgClientsWired
+    API doc: https://doc.mist-lab.fr/#operation/countOrgWiredClients
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id        
+    org_id : str        
     
     QUERY PARAMS
     ------------
-    :param str distinct(port_id, vlan, mac, device_mac, site_id, type)
-    :param int page
-    :param int limit
-    :param int start
-    :param int end
-    :param str duration        
+    distinct : str{'port_id', 'vlan', 'mac', 'device_mac', 'site_id', 'type'}, default: mac
+    page : int, default: 1
+    limit : int, default: 100
+    start : int
+    end : int
+    duration : str, default: 1d        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/wired_clients/count"
     query_params={}
@@ -49,36 +52,48 @@ def countOrgClientsWired(mist_session:_APISession, org_id:str, distinct:str="mac
     resp = mist_session.mist_get(uri=uri, query=query_params)
     return resp
     
-def searchOrgClientsWired(mist_session:_APISession, org_id:str, site_id:str=None, device_mac:str=None, mac:str=None, port_id:str=None, vlan:int=None, ip:str=None, manufacture:str=None, text:str=None, limit:int=100, start:int=None, end:int=None, duration:str="1d") -> _APIResponse:
+def searchOrgWiredClients(mist_session:_APISession, org_id:str, site_id:str=None, device_mac:str=None, mac:str=None, port_id:str=None, vlan:int=None, ip:str=None, manufacture:str=None, text:str=None, nacrule_id:str=None, limit:int=100, start:int=None, end:int=None, duration:str="1d") -> _APIResponse:
     """
-    API doc: https://doc.mist-lab.fr/#operation/searchOrgClientsWired
+    API doc: https://doc.mist-lab.fr/#operation/searchOrgWiredClients
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str org_id        
+    org_id : str        
     
     QUERY PARAMS
     ------------
-    :param str site_id - Site ID
-    :param str device_mac - device mac
-    :param str mac - client mac
-    :param str port_id - port id
-    :param int vlan - vlan
-    :param str ip - ip
-    :param str manufacture - client manufacture
-    :param str text - single entry of hostname/mac
-    :param int limit
-    :param int start
-    :param int end
-    :param str duration        
+    site_id : str
+      Site ID
+    device_mac : str
+      device mac
+    mac : str
+      client mac
+    port_id : str
+      port id
+    vlan : int
+      vlan
+    ip : str
+      ip
+    manufacture : str
+      client manufacturer
+    text : str
+      single entry of hostname/mac
+    nacrule_id : str
+      nacrule_id
+    limit : int, default: 100
+    start : int
+    end : int
+    duration : str, default: 1d        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/orgs/{org_id}/wired_clients/search"
     query_params={}
@@ -90,6 +105,7 @@ def searchOrgClientsWired(mist_session:_APISession, org_id:str, site_id:str=None
     if ip: query_params["ip"]=ip
     if manufacture: query_params["manufacture"]=manufacture
     if text: query_params["text"]=text
+    if nacrule_id: query_params["nacrule_id"]=nacrule_id
     if limit: query_params["limit"]=limit
     if start: query_params["start"]=start
     if end: query_params["end"]=end
