@@ -12,6 +12,7 @@
 
 from mistapi import APISession as _APISession
 from mistapi.__api_response import APIResponse as _APIResponse
+import deprecation
 
 def generateQrCodeForVerification(mist_session:_APISession, by:str="qrcode") -> _APIResponse:
     """
@@ -19,15 +20,18 @@ def generateQrCodeForVerification(mist_session:_APISession, by:str="qrcode") ->
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     QUERY PARAMS
     ------------
-    :param str by(qrcode)        
+    by : str{'qrcode'}, default: qrcode
+      if `by`==`qrcode`, returns the secret as a qrcode image        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/self/two_factor/token"
     query_params={}
@@ -41,11 +45,18 @@ def verifyTwoFactor(mist_session:_APISession, body:object) -> _APIResponse:
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
+    
+    BODY PARAMS
+    -----------
+    body : dict
+        JSON object to send to Mist Cloud (see API doc above for more details)
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/self/two_factor/verify"
     resp = mist_session.mist_post(uri=uri, body=body)
