@@ -12,6 +12,7 @@
 
 from mistapi import APISession as _APISession
 from mistapi.__api_response import APIResponse as _APIResponse
+import deprecation
 
 def getSiteSleClassifierDetails(mist_session:_APISession, site_id:str, scope:str, scope_id:str, metric:str, classifier:str, start:int=None, end:int=None, duration:str="1d") -> _APIResponse:
     """
@@ -19,27 +20,31 @@ def getSiteSleClassifierDetails(mist_session:_APISession, site_id:str, scope:str
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str site_id
-    :param str scope
-    :param str scope_id - * site_id if `scope`==`site`
+    site_id : str
+    scope : str
+    scope_id : str
+      * site_id if `scope`==`site`
 * device_id if `scope`==`ap`, `scope`==`switch` or `scope`==`gateway`
 * mac if `scope`==`client`
-    :param str metric - values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics
-    :param str classifier        
+    metric : str
+      values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics
+    classifier : str        
     
     QUERY PARAMS
     ------------
-    :param int start
-    :param int end
-    :param str duration        
+    start : int
+    end : int
+    duration : str, default: 1d        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/classifier/{classifier}/summary"
     query_params={}
@@ -55,20 +60,24 @@ def getSiteSleMetricClassifiers(mist_session:_APISession, site_id:str, scope:str
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str site_id
-    :param str scope
-    :param str scope_id - * site_id if `scope`==`site`
+    site_id : str
+    scope : str
+    scope_id : str
+      * site_id if `scope`==`site`
 * device_id if `scope`==`ap`, `scope`==`switch` or `scope`==`gateway`
 * mac if `scope`==`client`
-    :param str metric -  values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
+    metric : str
+      values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/classifiers"
     query_params={}
@@ -81,26 +90,30 @@ def getSiteSleHistogram(mist_session:_APISession, site_id:str, scope:str, scope_
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str site_id
-    :param str scope
-    :param str scope_id - * site_id if `scope`==`site`
+    site_id : str
+    scope : str
+    scope_id : str
+      * site_id if `scope`==`site`
 * device_id if `scope`==`ap`, `scope`==`switch` or `scope`==`gateway`
 * mac if `scope`==`client`
-    :param str metric - values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
+    metric : str
+      values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
     
     QUERY PARAMS
     ------------
-    :param int start
-    :param int end
-    :param str duration        
+    start : int
+    end : int
+    duration : str, default: 1d        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/histogram"
     query_params={}
@@ -116,28 +129,32 @@ def getSiteSleImpactSummary(mist_session:_APISession, site_id:str, scope:str, sc
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str site_id
-    :param str scope
-    :param str scope_id - * site_id if `scope`==`site`
+    site_id : str
+    scope : str
+    scope_id : str
+      * site_id if `scope`==`site`
 * device_id if `scope`==`ap`, `scope`==`switch` or `scope`==`gateway`
 * mac if `scope`==`client`
-    :param str metric - values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
+    metric : str
+      values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
     
     QUERY PARAMS
     ------------
-    :param int start
-    :param int end
-    :param str duration
-    :param str fields(wlan, device_type, device_os, band, ap, server, mxedge, switch, client, vlan, interface, chassis, gateway, peer_path, gateway_zones)
-    :param str classifier        
+    start : int
+    end : int
+    duration : str, default: 1d
+    fields : str{'wlan', 'device_type', 'device_os', 'band', 'ap', 'server', 'mxedge', 'switch', 'client', 'vlan', 'interface', 'chassis', 'gateway', 'peer_path', 'gateway_zones'}
+    classifier : str        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/impact-summary"
     query_params={}
@@ -155,25 +172,28 @@ def getSiteSleImpactedApplications(mist_session:_APISession, site_id:str, scope:
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str site_id
-    :param str scope
-    :param str scope_id
-    :param str metric - values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
+    site_id : str
+    scope : str
+    scope_id : str
+    metric : str
+      values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
     
     QUERY PARAMS
     ------------
-    :param int start
-    :param int end
-    :param str duration
-    :param str classifier        
+    start : int
+    end : int
+    duration : str, default: 1d
+    classifier : str        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/impacted-applications"
     query_params={}
@@ -190,25 +210,28 @@ def getSiteSleImpactedAps(mist_session:_APISession, site_id:str, scope:str, scop
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str site_id
-    :param str scope
-    :param str scope_id
-    :param str metric - values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
+    site_id : str
+    scope : str
+    scope_id : str
+    metric : str
+      values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
     
     QUERY PARAMS
     ------------
-    :param int start
-    :param int end
-    :param str duration
-    :param str classifier        
+    start : int
+    end : int
+    duration : str, default: 1d
+    classifier : str        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/impacted-aps"
     query_params={}
@@ -225,25 +248,28 @@ def getSiteSleImpactedChassis(mist_session:_APISession, site_id:str, scope:str,
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str site_id
-    :param str scope
-    :param str scope_id
-    :param str metric - values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
+    site_id : str
+    scope : str
+    scope_id : str
+    metric : str
+      values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
     
     QUERY PARAMS
     ------------
-    :param int start
-    :param int end
-    :param str duration
-    :param str classifier        
+    start : int
+    end : int
+    duration : str, default: 1d
+    classifier : str        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/impacted-chassis"
     query_params={}
@@ -260,25 +286,28 @@ def getSiteSleImpactedWiredClients(mist_session:_APISession, site_id:str, scope:
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str site_id
-    :param str scope
-    :param str scope_id
-    :param str metric - values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
+    site_id : str
+    scope : str
+    scope_id : str
+    metric : str
+      values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
     
     QUERY PARAMS
     ------------
-    :param int start
-    :param int end
-    :param str duration
-    :param str classifier        
+    start : int
+    end : int
+    duration : str, default: 1d
+    classifier : str        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/impacted-clients"
     query_params={}
@@ -295,25 +324,28 @@ def getSiteSleImpactedGateways(mist_session:_APISession, site_id:str, scope:str,
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str site_id
-    :param str scope
-    :param str scope_id
-    :param str metric - values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
+    site_id : str
+    scope : str
+    scope_id : str
+    metric : str
+      values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
     
     QUERY PARAMS
     ------------
-    :param int start
-    :param int end
-    :param str duration
-    :param str classifier        
+    start : int
+    end : int
+    duration : str, default: 1d
+    classifier : str        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/impacted-gateways"
     query_params={}
@@ -330,25 +362,28 @@ def getSiteSleImpactedInterfaces(mist_session:_APISession, site_id:str, scope:st
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str site_id
-    :param str scope
-    :param str scope_id
-    :param str metric - values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
+    site_id : str
+    scope : str
+    scope_id : str
+    metric : str
+      values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
     
     QUERY PARAMS
     ------------
-    :param int start
-    :param int end
-    :param str duration
-    :param str classifier        
+    start : int
+    end : int
+    duration : str, default: 1d
+    classifier : str        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/impacted-interfaces"
     query_params={}
@@ -365,25 +400,28 @@ def getSiteSleImpactedSwitches(mist_session:_APISession, site_id:str, scope:str,
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str site_id
-    :param str scope
-    :param str scope_id
-    :param str metric - values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
+    site_id : str
+    scope : str
+    scope_id : str
+    metric : str
+      values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
     
     QUERY PARAMS
     ------------
-    :param int start
-    :param int end
-    :param str duration
-    :param str classifier        
+    start : int
+    end : int
+    duration : str, default: 1d
+    classifier : str        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/impacted-switches"
     query_params={}
@@ -400,25 +438,28 @@ def getSiteSleImpactedWirelessClients(mist_session:_APISession, site_id:str, sco
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str site_id
-    :param str scope
-    :param str scope_id
-    :param str metric - values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
+    site_id : str
+    scope : str
+    scope_id : str
+    metric : str
+      values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
     
     QUERY PARAMS
     ------------
-    :param int start
-    :param int end
-    :param str duration
-    :param str classifier        
+    start : int
+    end : int
+    duration : str, default: 1d
+    classifier : str        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/impacted-users"
     query_params={}
@@ -435,26 +476,30 @@ def getSiteSleSummary(mist_session:_APISession, site_id:str, scope:str, scope_id
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str site_id
-    :param str scope
-    :param str scope_id - * site_id if `scope`==`site`
+    site_id : str
+    scope : str
+    scope_id : str
+      * site_id if `scope`==`site`
 * device_id if `scope`==`ap`, `scope`==`switch` or `scope`==`gateway`
 * mac if `scope`==`client`
-    :param str metric - values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
+    metric : str
+      values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
     
     QUERY PARAMS
     ------------
-    :param int start
-    :param int end
-    :param str duration        
+    start : int
+    end : int
+    duration : str, default: 1d        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/summary"
     query_params={}
@@ -470,20 +515,24 @@ def getSiteSleThreshold(mist_session:_APISession, site_id:str, scope:str, scope_
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str site_id
-    :param str scope
-    :param str scope_id - * site_id if `scope`==`site`
+    site_id : str
+    scope : str
+    scope_id : str
+      * site_id if `scope`==`site`
 * device_id if `scope`==`ap`, `scope`==`switch` or `scope`==`gateway`
 * mac if `scope`==`client`
-    :param str metric - values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
+    metric : str
+      values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/threshold"
     query_params={}
@@ -496,20 +545,29 @@ def replaceSiteSleThreshold(mist_session:_APISession, site_id:str, scope:str, sc
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str site_id
-    :param str scope
-    :param str scope_id - * site_id if `scope`==`site`
+    site_id : str
+    scope : str
+    scope_id : str
+      * site_id if `scope`==`site`
 * device_id if `scope`==`ap`, `scope`==`switch` or `scope`==`gateway`
 * mac if `scope`==`client`
-    :param str metric - values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
+    metric : str
+      values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
+    
+    BODY PARAMS
+    -----------
+    body : dict
+        JSON object to send to Mist Cloud (see API doc above for more details)
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/threshold"
     resp = mist_session.mist_post(uri=uri, body=body)
@@ -521,20 +579,29 @@ def updateSiteSleThreshold(mist_session:_APISession, site_id:str, scope:str, sco
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str site_id
-    :param str scope
-    :param str scope_id - * site_id if `scope`==`site`
+    site_id : str
+    scope : str
+    scope_id : str
+      * site_id if `scope`==`site`
 * device_id if `scope`==`ap`, `scope`==`switch` or `scope`==`gateway`
 * mac if `scope`==`client`
-    :param str metric - values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
+    metric : str
+      values from /api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics        
+    
+    BODY PARAMS
+    -----------
+    body : dict
+        JSON object to send to Mist Cloud (see API doc above for more details)
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metric/{metric}/threshold"
     resp = mist_session.mist_put(uri=uri, body=body)
@@ -546,19 +613,22 @@ def getSiteSlesMetrics(mist_session:_APISession, site_id:str, scope:str, scope_i
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str site_id
-    :param str scope
-    :param str scope_id - * site_id if `scope`==`site`
+    site_id : str
+    scope : str
+    scope_id : str
+      * site_id if `scope`==`site`
 * device_id if `scope`==`ap`, `scope`==`switch` or `scope`==`gateway`
 * mac if `scope`==`client`        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/sle/{scope}/{scope_id}/metrics"
     query_params={}
