@@ -12,35 +12,42 @@
 
 from mistapi import APISession as _APISession
 from mistapi.__api_response import APIResponse as _APIResponse
+import deprecation
 
-def countSiteClientsWired(mist_session:_APISession, site_id:str, distinct:str="mac", mac:str=None, device_mac:str=None, port_id:str=None, vlan:str=None, page:int=1, limit:int=100, start:int=None, end:int=None, duration:str="1d") -> _APIResponse:
+def countSiteWiredClients(mist_session:_APISession, site_id:str, distinct:str="mac", mac:str=None, device_mac:str=None, port_id:str=None, vlan:str=None, page:int=1, limit:int=100, start:int=None, end:int=None, duration:str="1d") -> _APIResponse:
     """
-    API doc: https://doc.mist-lab.fr/#operation/countSiteClientsWired
+    API doc: https://doc.mist-lab.fr/#operation/countSiteWiredClients
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str site_id        
+    site_id : str        
     
     QUERY PARAMS
     ------------
-    :param str distinct(port_id, vlan, mac)
-    :param str mac - client mac
-    :param str device_mac - device mac
-    :param str port_id - port id
-    :param str vlan - vlan
-    :param int page
-    :param int limit
-    :param int start
-    :param int end
-    :param str duration        
+    distinct : str{'port_id', 'vlan', 'mac'}, default: mac
+    mac : str
+      client mac
+    device_mac : str
+      device mac
+    port_id : str
+      port id
+    vlan : str
+      vlan
+    page : int, default: 1
+    limit : int, default: 100
+    start : int
+    end : int
+    duration : str, default: 1d        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/wired_clients/count"
     query_params={}
@@ -57,45 +64,57 @@ def countSiteClientsWired(mist_session:_APISession, site_id:str, distinct:str="m
     resp = mist_session.mist_get(uri=uri, query=query_params)
     return resp
     
-def searchSiteClientsWired(mist_session:_APISession, site_id:str, device_mac:str=None, mac:str=None, port_id:str=None, vlan:str=None, ip_address:str=None, manufacture:str=None, text:str=None, limit:int=100, start:int=None, end:int=None, duration:str="1d") -> _APIResponse:
+def searchSiteWiredClients(mist_session:_APISession, site_id:str, device_mac:str=None, mac:str=None, ip:str=None, port_id:str=None, vlan:str=None, manufacture:str=None, text:str=None, nacrule_id:str=None, limit:int=100, start:int=None, end:int=None, duration:str="1d") -> _APIResponse:
     """
-    API doc: https://doc.mist-lab.fr/#operation/searchSiteClientsWired
+    API doc: https://doc.mist-lab.fr/#operation/searchSiteWiredClients
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
     
     PATH PARAMS
     -----------
-    :param str site_id        
+    site_id : str        
     
     QUERY PARAMS
     ------------
-    :param str device_mac - device mac
-    :param str mac - client mac
-    :param str port_id - port id
-    :param str vlan - vlan
-    :param str ip_address
-    :param str manufacture - manufacture
-    :param str text - single entry of hostname/mac
-    :param int limit
-    :param int start
-    :param int end
-    :param str duration        
+    device_mac : str
+      device mac
+    mac : str
+      client mac
+    ip : str
+      client ip
+    port_id : str
+      port id
+    vlan : str
+      vlan
+    manufacture : str
+      manufacture
+    text : str
+      single entry of hostname/mac
+    nacrule_id : str
+      nacrule_id
+    limit : int, default: 100
+    start : int
+    end : int
+    duration : str, default: 1d        
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/sites/{site_id}/wired_clients/search"
     query_params={}
     if device_mac: query_params["device_mac"]=device_mac
     if mac: query_params["mac"]=mac
+    if ip: query_params["ip"]=ip
     if port_id: query_params["port_id"]=port_id
     if vlan: query_params["vlan"]=vlan
-    if ip_address: query_params["ip_address"]=ip_address
     if manufacture: query_params["manufacture"]=manufacture
     if text: query_params["text"]=text
+    if nacrule_id: query_params["nacrule_id"]=nacrule_id
     if limit: query_params["limit"]=limit
     if start: query_params["start"]=start
     if end: query_params["end"]=end
