@@ -12,21 +12,28 @@
 
 from mistapi import APISession as _APISession
 from mistapi.__api_response import APIResponse as _APIResponse
+import deprecation
 
-def testSiteWlanTelstraSetup(mist_session:_APISession) -> _APIResponse:
+def testSiteWlanTelstraSetup(mist_session:_APISession, body:object) -> _APIResponse:
     """
     API doc: https://doc.mist-lab.fr/#operation/testSiteWlanTelstraSetup
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
+    
+    BODY PARAMS
+    -----------
+    body : dict
+        JSON object to send to Mist Cloud (see API doc above for more details)
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/utils/test_telstra"
-    query_params={}
-    resp = mist_session.mist_get(uri=uri, query=query_params)
+    resp = mist_session.mist_post(uri=uri, body=body)
     return resp
     
\ No newline at end of file
