@@ -12,6 +12,7 @@
 
 from mistapi import APISession as _APISession
 from mistapi.__api_response import APIResponse as _APIResponse
+import deprecation
 
 def testSiteWlanTwilioSetup(mist_session:_APISession, body:object) -> _APIResponse:
     """
@@ -19,11 +20,18 @@ def testSiteWlanTwilioSetup(mist_session:_APISession, body:object) -> _APIRespon
     
     PARAMS
     -----------
-    :param APISession mist_session - mistapi session including authentication and Mist host information
+    mistapi.APISession : mist_session
+        mistapi session including authentication and Mist host information
+    
+    BODY PARAMS
+    -----------
+    body : dict
+        JSON object to send to Mist Cloud (see API doc above for more details)
     
     RETURN
     -----------
-    :return APIResponse - response from the API call
+    mistapi.APIResponse
+        response from the API call
     """
     uri = f"/api/v1/utils/test_twilio"
     resp = mist_session.mist_post(uri=uri, body=body)
